#
# spec file for package libnbd
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover 0

Name:           libnbd
Version:        1.18.1
Release:        150600.16.4
Summary:        NBD client library in userspace
License:        LGPL-2.1-or-later
URL:            https://gitlab.com/nbdkit/libnbd
Source0:        %{name}-%{version}.tar.bz2
Patch0:         4451e5b6-CVE-2023-5871.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  fdupes
BuildRequires:  libtool
BuildRequires:  ocaml-findlib
BuildRequires:  pkg-config
BuildRequires:  ocaml-rpm-macros
BuildRequires:  ocaml(compiler)
BuildRequires:  perl(Pod::Man)
BuildRequires:  perl(Pod::Simple)
BuildRequires:  pkgconfig(bash-completion)
BuildRequires:  pkgconfig(fuse3)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gnutls) >= 3.3.0
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(python3)
Requires:       libnbd%{sover} = %{version}
# Only for running the test suite.
BuildRequires:  gcc-c++
BuildRequires:  jq
%if 0%{?suse_version} >= 1550
BuildRequires:  nbd
%endif
BuildRequires:  qemu-tools

%description
NBD — Network Block Device — is a protocol for accessing Block Devices
(hard disks and disk-like things) over a Network.

This is the NBD client library in userspace, a simple library for
writing NBD clients.

The key features are:

 * Synchronous and asynchronous APIs, both for ease of use and for
   writing non-blocking, multithreaded clients.

 * High performance.

 * Minimal dependencies for the basic library.

 * Well-documented, stable API.

 * Bindings in several programming languages.

%package -n libnbd%{sover}
Summary:        Core library for nbd

%description -n libnbd%{sover}
This is the NBD client library in userspace, a simple library for
writing NBD clients.

%package devel
Summary:        Development headers for %{name}
Requires:       libnbd%{sover} = %{version}-%{release}

%description devel
This package contains development headers for %{name}.

%package -n python3-%{name}
Summary:        Python 3 bindings for %{name}
Requires:       libnbd%{sover} = %{version}-%{release}

%description -n python3-%{name}
python3-%{name} contains Python 3 bindings for %{name}.

%package -n nbdfuse
Summary:        FUSE support for %{name}
Requires:       libnbd%{sover} = %{version}-%{release}

%description -n nbdfuse
This package contains FUSE support for %{name}.

%package bash-completion
Summary:        Bash tab-completion for %{name}
BuildArch:      noarch
Requires:       bash-completion >= 2.0
Requires:       libnbd%{sover} = %{version}-%{release}

%description bash-completion
Install this package if you want intelligent bash tab-completion
for %{name}.

%prep
%autosetup -p1

%build
%define _lto_cflags %{nil}
autoreconf -fiv
%configure \
    --enable-fuse \
    --disable-golang \
    PYTHON=%{__python3} \
    --enable-python \
    --disable-static \
    %{nil}

%make_build

%install
%make_install
%fdupes %{buildroot}
# Delete libtool crap.
find "%{buildroot}" -name '*.la' -delete

# Delete the golang man page since we're not distributing the bindings.
rm %{buildroot}/%{_mandir}/man3/libnbd-golang.3*

%ocaml_create_file_list

%check
# All fuse tests fail in Koji with:
# fusermount: entry for fuse/test-*.d not found in /etc/mtab
# for unknown reasons but probably related to the Koji environment.
for f in fuse/test-*.sh; do
    rm $f
    touch $f
    chmod +x $f
done

%make_build check || {
    for f in $(find . -name test-suite.log); do
        echo
        echo "==== $f ===="
        cat $f
    done
  }

%post   -n libnbd%{sover} -p /sbin/ldconfig
%postun -n libnbd%{sover} -p /sbin/ldconfig

%files
%doc README.md
%{_bindir}/nbdcopy
%{_bindir}/nbddump
%{_bindir}/nbdinfo
%{_mandir}/man1/nbdcopy.1*
%{_mandir}/man1/nbddump.1*
%{_mandir}/man1/nbdinfo.1*

%files -n libnbd%{sover} -f %name.files
%license COPYING.LIB
%{_libdir}/libnbd.so.%{sover}
%{_libdir}/libnbd.so.%{sover}.*

%files devel -f %name.files.devel
%{_includedir}/libnbd.h
%{_libdir}/libnbd.so
%{_libdir}/pkgconfig/libnbd.pc
%{_mandir}/man3/libnbd.3*
%{_mandir}/man3/libnbd-ocaml.3.gz
%{_mandir}/man1/libnbd-release-notes-1.*.1*
%{_mandir}/man3/libnbd-security.3*
%{_mandir}/man3/nbd_*.3*

%files -n python3-%{name}
%{python3_sitearch}/libnbdmod*.so
%{python3_sitearch}/nbd.py
%{python3_sitearch}/nbdsh.py
%{_bindir}/nbdsh
%{_mandir}/man1/nbdsh.1*

%files -n nbdfuse
%{_bindir}/nbdfuse
%{_mandir}/man1/nbdfuse.1*

%files bash-completion
%{_datadir}/bash-completion

%changelog
* Tue Dec 12 2023 ohering@suse.de
- Use ocaml-rpm-macros to track OCaml ABI
* Mon Nov 13 2023 jfehlig@suse.com
- Fix assertion in ext-mode BLOCK_STATUS, CVE-2023-5871
  4451e5b6-CVE-2023-5871.patch
  bsc#1216769
* Wed Oct 25 2023 jfehlig@suse.com
- Update to version 1.18.1:
  * Version 1.18.1.
  * rust: Use string_starts_with instead of String.starts_with
  * rust: Build the examples
  * rust: Write a custom translator from POD to rustdoc
  * rust: Add overview documentation
  * rust: Annotate 'endif' with corresponding label
  * utils: Slightly simplify human_size()
  * docs: Assign CVE-2023-5215 to nbd_get_size negative result issue
* Fri Sep 29 2023 jfehlig@suse.com
- Update to version 1.18.0:
  * CVE-2023-5215 (bsc#1215799)
  * docs: Add link to nbd_get_size announcement in release notes
  * docs: Add URL to list post on nbd_get_size security
  * docs: Update release notes for nbd_get_size backport to 1.16.5
  * docs: Finalize release notes for release tomorrow
  * dump: Add more examples of running subprocesses from nbddump
  * info: Tolerate missing size
  * block_status: Fix assertion on bad 64-bit block status reply
  * block_status: Fix assertion with large server size
  * api: Sanitize sizes larger than INT64_MAX
* Fri Oct 14 2022 jfehlig@suse.com
- spec: Don't set tls priority to unavailable crypto policy
* Fri Jul  8 2022 jfehlig@suse.com
- Update to version 1.12.4:
  * python: Correctly use PyGILState
  * olang: aio_buffer.go: Explicit panic() on invalid usage
  * python: Enhance tests of nbd.Buffer
  * python: Plug uninit leak in nbd.Buffer.to_bytearray
  * python: Avoid memleak on (unlikely) module failure
  * python: Accept buffers in nbd.Buffer.from_bytearray()
  * Dropped patches:
    794c8ce0-copy-dummy-vs-errno.patch,
    8d444b41-CVE-2022-0485.patch
  * jsc#ECO-3633
- Enable building python module and utilities
* Thu Feb 10 2022 jfehlig@suse.com
- copy: CVE-2022-0485: Fail nbdcopy if NBD read or write fails
  794c8ce0-copy-dummy-vs-errno.patch,
  8d444b41-CVE-2022-0485.patch
  bsc#1195636
* Wed Aug 25 2021 jfehlig@suse.com
- Update to version 1.9.3:
  * Version 1.9.3.
  * maint: Modernize configure.ac to silence autoreconf warnings
  * maint: Update to latest ax_pthread.m4
  * copy: Avoid potential divide by zero when source size is zero
  * copy: Test corner case of copying from zero-sized source
  * copy: Fix progress bar
  * Update CI files once more
  * ci: Allow failure when building fedora rawhide container
  * ci: Consolidate refresh scripts
  * macOS: Simple cloexec/nonblock fix
  * info: Require can_cache for info-can.sh
  * CI: Add testing on Alpine
  * Update CI files
  * macOS: Do not use --version_script
  * One more VSOCK include fix
  * m4: Remove *~ on make clean
  * ci: Rework the build script to run check-valgrind properly
  * fuse: move check-valgrind out from condition
  * qemu-storage-daemon 5.2.0 is still broken
  * Version 1.9.2.
  * python: Add missing test file to EXTRA_DIST
  * build: Warn about large stack frames
  * configure: Add a macro to test if compiler -W warning flags work
  * lib/uri.c: nbd_get_uri: Do not translate port name into service
  * python: Implement nbd.aio_connect for AF_UNIX
  * bash: Generate completion files during build
  * info: Add percentage after field in --map --totals
  * info: Add --can|--is options to test for NBD flags
  * info: Add --map --totals sub-mode to display summary of map
  * info: Don't print extra trailing \n after output
  * fuse: Tidy up MODES section of the documentation
  * fuse: Note in docs that read-only server implies -r flag
  * fuse: Improve documentation on the thread model
  * fuse: Update comment as we expect zero support to be present in 5.14
  * copy: Set default request-size to 2**18 (262144 bytes)
  * copy/copy-sparse-no-extents.sh: Set request-size explicitly
  * maint: Untabify configure.ac
* Thu Jul  1 2021 jfehlig@suse.com
- Update to version 1.9.1:
  * Version 1.9.1.
  * ci: Update build files
  * ci: Also perform `brew upgrade` on MacOS
  * ci: Only run `make check` on Linux
  * ci: Skip some broken tests/distro combinations
  * ci: Rename build_script.sh to just build.sh
  * ci: Add support for test skipping
  * ci: Some build script fixes
  * ci: Fix run commands in README
  * ci: Add support for FreeBSD-13.0
  * ci: Remove debian-10-clang build
  * ci: Remove cross-compilation targets
  * ci: Change docker driver and archive logs
  * tests: Rename version to get-version
  * tests: Do not use magic parameter for some nbdkit plugins
  * tests: Require cap_sys_admin where root is required
  * tests: Fix port randomisation
  * tests: Enhance fuse probing
  * tests: Clean up qemu-nbd detection
  * tests: Fix hexdump probing
  * interop: Do not test against broken qemu-storage-daemon
  * fuse: Only support defined fallocate modes
  * Include sys/vsock.h if linux/vm_sockets.h is not available
  * info: Avoid ambiguous 'allocated' terminology in --map
  * run: Unset DEBUGINFOD_URLS
  * ci/cirrus: Update system before doing anything else
* Wed Jun  9 2021 jfehlig@suse.com
- Update to version 1.8.0:
  * Version 1.8.0.
  * docs: Get release notes ready for a release today
  * copy/copy-file-to-qcow2.sh: Skip this test for old qemu-nbd
  * docs: Put links to release notes in a separate section
  * docs: Add preliminary release notes for libnbd 1.8
  * common/utils: Add test-vector.c (unit test for vectors) from nbdkit
  * copy, fuse, info: Synchronize --help output with manual
  * generator: Update copyright year in generated files.
  * Update README
  * Version 1.7.12.
* Wed Apr 14 2021 rpm@fthiessen.de
- Update to 1.7.7
  * Fixed CVE-2021-20286
  * Fix parsing and construction of IPv6 URIs
  * New API nbd_get_uri to get an NBD URI for a connection
  * Permit "see also" links to nbd_get_error and nbd_get_errno
  * Avoid over-long lines in POD.
  * Fix reporting of NBD URI support
  * Let exit status reflect any failures during NBD_OPT_INFO
  * Fix page eviction when len < page_size.
* Sun Mar 14 2021 jengelh@inai.de
- Specfile modernization
* Thu Feb 25 2021 jfehlig@suse.com
- spec: Only enable system nbd interop tests if
  suse_version >= 1550
* Tue Jan 26 2021 jfehlig@suse.com
- Initial packaging of libnbd:
  * Version 1.7.1.
  * sh: Add NOTES section.
  * copy: Update multi-conn documentation.
  * sh: Arrange --opt-mode documentation in alphabetical order.
  * python: Add example.
  * copy: Fix initialization complaint with ancient GCC on RHEL 7.
  * python: Fix Python style error.
  * copy/file-ops.c: Small whitespace fix.
  * copy/copy-nbd-to-sparse-file.sh: Skip test unless nbdkit available.
